@@ -64,6 +64,7 @@ public:
     QAction * mActEnableWifi;
     QAction * mActConnInfo;
     QAction * mActDebugInfo;
+    QAction * mRequestScan;
     NmModel mNmModel;
     NmProxy mActiveConnections;
     QPersistentModelIndex mPrimaryConnection;
@@ -256,6 +257,7 @@ Tray::Tray(QObject *parent/* = nullptr*/)
     d->mContextMenu.addSeparator();
     d->mActConnInfo = d->mContextMenu.addAction(QIcon::fromTheme(QStringLiteral("dialog-information")), Tray::tr("Connection information"));
     d->mActDebugInfo = d->mContextMenu.addAction(QIcon::fromTheme(QStringLiteral("dialog-information")), Tray::tr("Debug information"));
+    d->mRequestScan = d->mContextMenu.addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), Tray::tr("Wifi - request scan"));
     connect(d->mContextMenu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), Tray::tr("Edit connections...")), &QAction::triggered
             , this, &Tray::onEditConnectionsTriggered);
     d->mContextMenu.addSeparator();
@@ -270,10 +272,10 @@ Tray::Tray(QObject *parent/* = nullptr*/)
     d->mActEnableWifi->setCheckable(true);
     enable_notifications->setCheckable(true);
     enable_notifications->setChecked(d->mEnableNotifications);
-    connect(d->mActEnableNetwork, &QAction::triggered, [this] (bool checked) { NetworkManager::setNetworkingEnabled(checked); });
-    connect(d->mActEnableWifi, &QAction::triggered, [this] (bool checked) { NetworkManager::setWirelessEnabled(checked); });
-    connect(enable_notifications, &QAction::triggered, [this] (bool checked) { d->mEnableNotifications = checked; QSettings{}.setValue(ENABLE_NOTIFICATIONS, checked); });
-    connect(d->mActConnInfo, &QAction::triggered, [this] (bool ) {
+    connect(d->mActEnableNetwork, &QAction::triggered, [] (bool checked) { NetworkManager::setNetworkingEnabled(checked); });
+    connect(d->mActEnableWifi, &QAction::triggered, [] (bool checked) { NetworkManager::setWirelessEnabled(checked); });
+    connect(enable_notifications, &QAction::triggered, this, [this] (bool checked) { d->mEnableNotifications = checked; QSettings{}.setValue(ENABLE_NOTIFICATIONS, checked); });
+    connect(d->mActConnInfo, &QAction::triggered, this, [this] (bool ) {
         if (d->mInfoDialog.isNull())
         {
             d->mInfoDialog.reset(new ConnectionInfo{&d->mNmModel});
@@ -283,7 +285,7 @@ Tray::Tray(QObject *parent/* = nullptr*/)
         }
         d->openCloseDialog(d->mInfoDialog.data());
     });
-    connect(d->mActDebugInfo, &QAction::triggered, [this] (bool ) {
+    connect(d->mActDebugInfo, &QAction::triggered, this, [this] (bool ) {
         if (d->mConnDialog.isNull())
         {
             d->mConnDialog.reset(new NmList{Tray::tr("nm-tray info"), &d->mNmModel});
@@ -293,6 +295,7 @@ Tray::Tray(QObject *parent/* = nullptr*/)
         }
         d->openCloseDialog(d->mConnDialog.data());
     });
+    connect(d->mRequestScan, &QAction::triggered, &d->mNmModel, &NmModel::requestAllWifiScan);
 
     // Note: Force all the updates as the NetworkManager::Notifier signals aren't
     // emitted at application startup.
@@ -414,7 +417,9 @@ void Tray::setActionsStates()
     d->mActEnableNetwork->setChecked(net_enabled);
 
     d->mActEnableWifi->setChecked(NetworkManager::isWirelessEnabled());
-    d->mActEnableWifi->setEnabled(NetworkManager::isNetworkingEnabled() && NetworkManager::isWirelessHardwareEnabled());
+    const bool wifi_enabled = NetworkManager::isNetworkingEnabled() && NetworkManager::isWirelessHardwareEnabled();
+    d->mActEnableWifi->setEnabled(wifi_enabled);
+    d->mRequestScan->setEnabled(wifi_enabled);
 
     d->mActConnInfo->setEnabled(net_enabled);
 }
