@@ -35,32 +35,32 @@
 <context>
     <name>NmModel</name>
     <message>
-        <location filename="../src/nmmodel.cpp" line="728"/>
+        <location filename="../src/nmmodel.cpp" line="744"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="730"/>
+        <location filename="../src/nmmodel.cpp" line="746"/>
         <source>active connection(s)</source>
         <translation>aktywne połączenia</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="732"/>
+        <location filename="../src/nmmodel.cpp" line="748"/>
         <source>connection(s)</source>
         <translation>połączenia</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="734"/>
+        <location filename="../src/nmmodel.cpp" line="750"/>
         <source>device(s)</source>
         <translation>urządzenia</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="736"/>
+        <location filename="../src/nmmodel.cpp" line="752"/>
         <source>wifi network(s)</source>
         <translation>sieci bezprzewodowe</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1027"/>
+        <location filename="../src/nmmodel.cpp" line="1043"/>
         <source>unknown</source>
         <comment>hardware address</comment>
         <translation>nieznany</translation>
@@ -76,84 +76,84 @@
         <translation>Potrzebne jest hasło, aby połączyć się z &apos;%1&apos;:</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1130"/>
+        <location filename="../src/nmmodel.cpp" line="1151"/>
         <source>General</source>
         <comment>Active connection information</comment>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1131"/>
+        <location filename="../src/nmmodel.cpp" line="1152"/>
         <source>Interface</source>
         <comment>Active connection information</comment>
         <translation>Interfejs</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1133"/>
+        <location filename="../src/nmmodel.cpp" line="1154"/>
         <source>Hardware Address</source>
         <comment>Active connection information</comment>
         <translation>Adres urządzenia</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1135"/>
+        <location filename="../src/nmmodel.cpp" line="1156"/>
         <source>Driver</source>
         <comment>Active connection information</comment>
         <translation>Informacje o aktywnym połączeniu</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1137"/>
+        <location filename="../src/nmmodel.cpp" line="1158"/>
         <source>Speed</source>
         <comment>Active connection information</comment>
         <translation>Prędkość</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1139"/>
+        <location filename="../src/nmmodel.cpp" line="1160"/>
         <source> Kb/s</source>
         <translation> Kb/s</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1141"/>
+        <location filename="../src/nmmodel.cpp" line="1162"/>
         <source>unknown</source>
         <comment>Speed</comment>
         <translation>nieznana</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1145"/>
+        <location filename="../src/nmmodel.cpp" line="1166"/>
         <source>Security</source>
         <comment>Active connection information</comment>
         <translation>Bezpieczeństwo</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1149"/>
+        <location filename="../src/nmmodel.cpp" line="1170"/>
         <source>IPv4</source>
         <comment>Active connection information</comment>
         <translation>IPv4</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1150"/>
+        <location filename="../src/nmmodel.cpp" line="1171"/>
         <source>IPv6</source>
         <comment>Active connection information</comment>
         <translation>IPv6</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1161"/>
+        <location filename="../src/nmmodel.cpp" line="1182"/>
         <source>IP Address</source>
         <comment>Active connection information</comment>
         <translation>Adres IP</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1163"/>
+        <location filename="../src/nmmodel.cpp" line="1184"/>
         <source>Subnet Mask</source>
         <comment>Active connection information</comment>
         <translation>Maska podsieci</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1172"/>
+        <location filename="../src/nmmodel.cpp" line="1193"/>
         <source>Default route</source>
         <comment>Active connection information</comment>
         <translation>Brama domyślna</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1178"/>
+        <location filename="../src/nmmodel.cpp" line="1199"/>
         <source>DNS(%1)</source>
         <comment>Active connection information</comment>
         <translation>DNS(%1)</translation>
@@ -235,31 +235,36 @@
     </message>
     <message>
         <location filename="../src/tray.cpp" line="260"/>
+        <source>Wifi - request scan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/tray.cpp" line="261"/>
         <source>Edit connections...</source>
         <translation>Edytuj połączenia…</translation>
     </message>
     <message>
-        <location filename="../src/tray.cpp" line="263"/>
+        <location filename="../src/tray.cpp" line="264"/>
         <source>About</source>
         <translation>O programie</translation>
     </message>
     <message>
-        <location filename="../src/tray.cpp" line="265"/>
+        <location filename="../src/tray.cpp" line="266"/>
         <source>Quit</source>
         <translation>Zakończ</translation>
     </message>
     <message>
-        <location filename="../src/tray.cpp" line="382"/>
+        <location filename="../src/tray.cpp" line="384"/>
         <source>%1 about</source>
         <translation>o %1</translation>
     </message>
     <message>
-        <location filename="../src/tray.cpp" line="383"/>
+        <location filename="../src/tray.cpp" line="385"/>
         <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
         <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; jest prostą, napisaną w Qt nakładką dla &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManagera&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Wersja: %1</translation>
     </message>
     <message>
-        <location filename="../src/tray.cpp" line="290"/>
+        <location filename="../src/tray.cpp" line="291"/>
         <source>nm-tray info</source>
         <translation>Informacje o nm-tray</translation>
     </message>
